==> haskell-errors-2.2.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.2.2
id: errors-2.2.2-FdBXcdXXEp3LhB1wEZq71
key: errors-2.2.2-FdBXcdXXEp3LhB1wEZq71
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: 62e08dda4454524785b9319796c17f07
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/errors-2.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/errors-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/errors-2.2.2
hs-libraries: HSerrors-2.2.2-FdBXcdXXEp3LhB1wEZq71
depends:
    base-4.10.1.0 exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    unexceptionalio-0.3.0-9fFAwvA604gAsfj6S48PMd
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT=f624bf973f8eeff6578fe95732b4e11a
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             unexceptionalio-0.3.0-9fFAwvA604gAsfj6S48PMd=b0060eda9e5bf70b5274dae71e4aebcb
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.2.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.2.2
id: errors-2.2.2-KHdUGjK7Vw0E2pv3AiwfBz
key: errors-2.2.2-KHdUGjK7Vw0E2pv3AiwfBz
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: eda8e9aad8721fc0b81446f9742609bb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/errors-2.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/errors-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/errors-2.2.2
hs-libraries: HSerrors-2.2.2-KHdUGjK7Vw0E2pv3AiwfBz
depends:
    base-4.10.1.0 exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    unexceptionalio-0.3.0-9fFAwvA604gAsfj6S48PMd
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             unexceptionalio-0.3.0-9fFAwvA604gAsfj6S48PMd=b0060eda9e5bf70b5274dae71e4aebcb
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
